"Main interface for codestar Client"
from __future__ import annotations

from typing import Any, Dict, List
from botocore.client import BaseClient
from botocore.paginate import Paginator
from botocore.waiter import Waiter
from mypy_boto3_codestar.type_defs import (
    ClientAssociateTeamMemberResponseTypeDef,
    ClientCreateProjectResponseTypeDef,
    ClientCreateProjectsourceCodeTypeDef,
    ClientCreateProjecttoolchainTypeDef,
    ClientCreateUserProfileResponseTypeDef,
    ClientDeleteProjectResponseTypeDef,
    ClientDeleteUserProfileResponseTypeDef,
    ClientDescribeProjectResponseTypeDef,
    ClientDescribeUserProfileResponseTypeDef,
    ClientListProjectsResponseTypeDef,
    ClientListResourcesResponseTypeDef,
    ClientListTagsForProjectResponseTypeDef,
    ClientListTeamMembersResponseTypeDef,
    ClientListUserProfilesResponseTypeDef,
    ClientTagProjectResponseTypeDef,
    ClientUpdateTeamMemberResponseTypeDef,
    ClientUpdateUserProfileResponseTypeDef,
)


class Client(BaseClient):
    # pylint: disable=arguments-differ
    def associate_team_member(
        self,
        projectId: str,
        userArn: str,
        projectRole: str,
        clientRequestToken: str = None,
        remoteAccessAllowed: bool = None,
    ) -> ClientAssociateTeamMemberResponseTypeDef:
        """
        Adds an IAM user to the team for an AWS CodeStar project.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/AssociateTeamMember>`_

        **Request Syntax**
        ::

          response = client.associate_team_member(
              projectId='string',
              clientRequestToken='string',
              userArn='string',
              projectRole='string',
              remoteAccessAllowed=True|False
          )
        :type projectId: string
        :param projectId: **[REQUIRED]**

          The ID of the project to which you will add the IAM user.

        :type clientRequestToken: string
        :param clientRequestToken:

          A user- or system-generated token that identifies the entity that requested the team member
          association to the project. This token can be used to repeat the request.

        :type userArn: string
        :param userArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) for the IAM user you want to add to the AWS CodeStar project.

        :type projectRole: string
        :param projectRole: **[REQUIRED]**

          The AWS CodeStar project role that will apply to this user. This role determines what actions a
          user can take in an AWS CodeStar project.

        :type remoteAccessAllowed: boolean
        :param remoteAccessAllowed:

          Whether the team member is allowed to use an SSH public/private key pair to remotely access
          project resources, for example Amazon EC2 instances.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'clientRequestToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **clientRequestToken** *(string) --*

              The user- or system-generated token from the initial request that can be used to repeat the
              request.

        """

    # pylint: disable=arguments-differ
    def can_paginate(self, operation_name: str) -> None:
        """
        Check if an operation can be paginated.

        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you'd normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator("create_foo")``.

        :return: ``True`` if the operation can be paginated,
            ``False`` otherwise.
        """

    # pylint: disable=arguments-differ
    def create_project(
        self,
        name: str,
        id: str,
        description: str = None,
        clientRequestToken: str = None,
        sourceCode: List[ClientCreateProjectsourceCodeTypeDef] = None,
        toolchain: ClientCreateProjecttoolchainTypeDef = None,
        tags: Dict[str, str] = None,
    ) -> ClientCreateProjectResponseTypeDef:
        """
        Creates a project, including project resources. This action creates a project based on a submitted
        project request. A set of source code files and a toolchain template file can be included with the
        project request. If these are not provided, an empty project is created.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/CreateProject>`_

        **Request Syntax**
        ::

          response = client.create_project(
              name='string',
              id='string',
              description='string',
              clientRequestToken='string',
              sourceCode=[
                  {
                      'source': {
                          's3': {
                              'bucketName': 'string',
                              'bucketKey': 'string'
                          }
                      },
                      'destination': {
                          'codeCommit': {
                              'name': 'string'
                          },
                          'gitHub': {
                              'name': 'string',
                              'description': 'string',
                              'type': 'string',
                              'owner': 'string',
                              'privateRepository': True|False,
                              'issuesEnabled': True|False,
                              'token': 'string'
                          }
                      }
                  },
              ],
              toolchain={
                  'source': {
                      's3': {
                          'bucketName': 'string',
                          'bucketKey': 'string'
                      }
                  },
                  'roleArn': 'string',
                  'stackParameters': {
                      'string': 'string'
                  }
              },
              tags={
                  'string': 'string'
              }
          )
        :type name: string
        :param name: **[REQUIRED]**

          The display name for the project to be created in AWS CodeStar.

        :type id: string
        :param id: **[REQUIRED]**

          The ID of the project to be created in AWS CodeStar.

        :type description: string
        :param description:

          The description of the project, if any.

        :type clientRequestToken: string
        :param clientRequestToken:

          A user- or system-generated token that identifies the entity that requested project creation.
          This token can be used to repeat the request.

        :type sourceCode: list
        :param sourceCode:

          A list of the Code objects submitted with the project request. If this parameter is specified,
          the request must also include the toolchain parameter.

          - *(dict) --*

            Location and destination information about the source code files provided with the project
            request. The source code is uploaded to the new project source repository after project
            creation.

            - **source** *(dict) --* **[REQUIRED]**

              The location where the source code files provided with the project request are stored. AWS
              CodeStar retrieves the files during project creation.

              - **s3** *(dict) --* **[REQUIRED]**

                Information about the Amazon S3 location where the source code files provided with the
                project request are stored.

                - **bucketName** *(string) --*

                  The Amazon S3 bucket name where the source code files provided with the project request
                  are stored.

                - **bucketKey** *(string) --*

                  The Amazon S3 object key where the source code files provided with the project request
                  are stored.

            - **destination** *(dict) --* **[REQUIRED]**

              The repository to be created in AWS CodeStar. Valid values are AWS CodeCommit or GitHub.
              After AWS CodeStar provisions the new repository, the source code files provided with the
              project request are placed in the repository.

              - **codeCommit** *(dict) --*

                Information about the AWS CodeCommit repository to be created in AWS CodeStar. This is
                where the source code files provided with the project request will be uploaded after
                project creation.

                - **name** *(string) --* **[REQUIRED]**

                  The name of the AWS CodeCommit repository to be created in AWS CodeStar.

              - **gitHub** *(dict) --*

                Information about the GitHub repository to be created in AWS CodeStar. This is where the
                source code files provided with the project request will be uploaded after project creation.

                - **name** *(string) --* **[REQUIRED]**

                  Name of the GitHub repository to be created in AWS CodeStar.

                - **description** *(string) --*

                  Description for the GitHub repository to be created in AWS CodeStar. This description
                  displays in GitHub after the repository is created.

                - **type** *(string) --* **[REQUIRED]**

                  The type of GitHub repository to be created in AWS CodeStar. Valid values are User or
                  Organization.

                - **owner** *(string) --* **[REQUIRED]**

                  The GitHub username for the owner of the GitHub repository to be created in AWS CodeStar.
                  If this repository should be owned by a GitHub organization, provide its name.

                - **privateRepository** *(boolean) --* **[REQUIRED]**

                  Whether the GitHub repository is to be a private repository.

                - **issuesEnabled** *(boolean) --* **[REQUIRED]**

                  Whether to enable issues for the GitHub repository.

                - **token** *(string) --* **[REQUIRED]**

                  The GitHub user's personal access token for the GitHub repository.

        :type toolchain: dict
        :param toolchain:

          The name of the toolchain template file submitted with the project request. If this parameter is
          specified, the request must also include the sourceCode parameter.

          - **source** *(dict) --* **[REQUIRED]**

            The Amazon S3 location where the toolchain template file provided with the project request is
            stored. AWS CodeStar retrieves the file during project creation.

            - **s3** *(dict) --* **[REQUIRED]**

              The Amazon S3 bucket where the toolchain template file provided with the project request is
              stored.

              - **bucketName** *(string) --*

                The Amazon S3 bucket name where the source code files provided with the project request are
                stored.

              - **bucketKey** *(string) --*

                The Amazon S3 object key where the source code files provided with the project request are
                stored.

          - **roleArn** *(string) --*

            The service role ARN for AWS CodeStar to use for the toolchain template during stack
            provisioning.

          - **stackParameters** *(dict) --*

            The list of parameter overrides to be passed into the toolchain template during stack
            provisioning, if any.

            - *(string) --*

              - *(string) --*

        :type tags: dict
        :param tags:

          The tags created for the project.

          - *(string) --*

            - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'id': 'string',
                'arn': 'string',
                'clientRequestToken': 'string',
                'projectTemplateId': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **id** *(string) --*

              The ID of the project.

            - **arn** *(string) --*

              The Amazon Resource Name (ARN) of the created project.

            - **clientRequestToken** *(string) --*

              A user- or system-generated token that identifies the entity that requested project creation.

            - **projectTemplateId** *(string) --*

              Reserved for future use.

        """

    # pylint: disable=arguments-differ
    def create_user_profile(
        self,
        userArn: str,
        displayName: str,
        emailAddress: str,
        sshPublicKey: str = None,
    ) -> ClientCreateUserProfileResponseTypeDef:
        """
        Creates a profile for a user that includes user preferences, such as the display name and email
        address assocciated with the user, in AWS CodeStar. The user profile is not project-specific.
        Information in the user profile is displayed wherever the user's information appears to other users
        in AWS CodeStar.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/CreateUserProfile>`_

        **Request Syntax**
        ::

          response = client.create_user_profile(
              userArn='string',
              displayName='string',
              emailAddress='string',
              sshPublicKey='string'
          )
        :type userArn: string
        :param userArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the user in IAM.

        :type displayName: string
        :param displayName: **[REQUIRED]**

          The name that will be displayed as the friendly name for the user in AWS CodeStar.

        :type emailAddress: string
        :param emailAddress: **[REQUIRED]**

          The email address that will be displayed as part of the user's profile in AWS CodeStar.

        :type sshPublicKey: string
        :param sshPublicKey:

          The SSH public key associated with the user in AWS CodeStar. If a project owner allows the user
          remote access to project resources, this public key will be used along with the user's private
          key for SSH access.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'userArn': 'string',
                'displayName': 'string',
                'emailAddress': 'string',
                'sshPublicKey': 'string',
                'createdTimestamp': datetime(2015, 1, 1),
                'lastModifiedTimestamp': datetime(2015, 1, 1)
            }
          **Response Structure**

          - *(dict) --*

            - **userArn** *(string) --*

              The Amazon Resource Name (ARN) of the user in IAM.

            - **displayName** *(string) --*

              The name that is displayed as the friendly name for the user in AWS CodeStar.

            - **emailAddress** *(string) --*

              The email address that is displayed as part of the user's profile in AWS CodeStar.

            - **sshPublicKey** *(string) --*

              The SSH public key associated with the user in AWS CodeStar. This is the public portion of
              the public/private keypair the user can use to access project resources if a project owner
              allows the user remote access to those resources.

            - **createdTimestamp** *(datetime) --*

              The date the user profile was created, in timestamp format.

            - **lastModifiedTimestamp** *(datetime) --*

              The date the user profile was last modified, in timestamp format.

        """

    # pylint: disable=arguments-differ
    def delete_project(
        self, id: str, clientRequestToken: str = None, deleteStack: bool = None
    ) -> ClientDeleteProjectResponseTypeDef:
        """
        Deletes a project, including project resources. Does not delete users associated with the project,
        but does delete the IAM roles that allowed access to the project.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/DeleteProject>`_

        **Request Syntax**
        ::

          response = client.delete_project(
              id='string',
              clientRequestToken='string',
              deleteStack=True|False
          )
        :type id: string
        :param id: **[REQUIRED]**

          The ID of the project to be deleted in AWS CodeStar.

        :type clientRequestToken: string
        :param clientRequestToken:

          A user- or system-generated token that identifies the entity that requested project deletion.
          This token can be used to repeat the request.

        :type deleteStack: boolean
        :param deleteStack:

          Whether to send a delete request for the primary stack in AWS CloudFormation originally used to
          generate the project and its resources. This option will delete all AWS resources for the project
          (except for any buckets in Amazon S3) as well as deleting the project itself. Recommended for
          most use cases.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'stackId': 'string',
                'projectArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **stackId** *(string) --*

              The ID of the primary stack in AWS CloudFormation that will be deleted as part of deleting
              the project and its resources.

            - **projectArn** *(string) --*

              The Amazon Resource Name (ARN) of the deleted project.

        """

    # pylint: disable=arguments-differ
    def delete_user_profile(
        self, userArn: str
    ) -> ClientDeleteUserProfileResponseTypeDef:
        """
        Deletes a user profile in AWS CodeStar, including all personal preference data associated with that
        profile, such as display name and email address. It does not delete the history of that user, for
        example the history of commits made by that user.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/DeleteUserProfile>`_

        **Request Syntax**
        ::

          response = client.delete_user_profile(
              userArn='string'
          )
        :type userArn: string
        :param userArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the user to delete from AWS CodeStar.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'userArn': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **userArn** *(string) --*

              The Amazon Resource Name (ARN) of the user deleted from AWS CodeStar.

        """

    # pylint: disable=arguments-differ
    def describe_project(self, id: str) -> ClientDescribeProjectResponseTypeDef:
        """
        Describes a project and its resources.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/DescribeProject>`_

        **Request Syntax**
        ::

          response = client.describe_project(
              id='string'
          )
        :type id: string
        :param id: **[REQUIRED]**

          The ID of the project.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'name': 'string',
                'id': 'string',
                'arn': 'string',
                'description': 'string',
                'clientRequestToken': 'string',
                'createdTimeStamp': datetime(2015, 1, 1),
                'stackId': 'string',
                'projectTemplateId': 'string',
                'status': {
                    'state': 'string',
                    'reason': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **name** *(string) --*

              The display name for the project.

            - **id** *(string) --*

              The ID of the project.

            - **arn** *(string) --*

              The Amazon Resource Name (ARN) for the project.

            - **description** *(string) --*

              The description of the project, if any.

            - **clientRequestToken** *(string) --*

              A user- or system-generated token that identifies the entity that requested project creation.

            - **createdTimeStamp** *(datetime) --*

              The date and time the project was created, in timestamp format.

            - **stackId** *(string) --*

              The ID of the primary stack in AWS CloudFormation used to generate resources for the project.

            - **projectTemplateId** *(string) --*

              The ID for the AWS CodeStar project template used to create the project.

            - **status** *(dict) --*

              The project creation or deletion status.

              - **state** *(string) --*

                The phase of completion for a project creation or deletion.

              - **reason** *(string) --*

                In the case of a project creation or deletion failure, a reason for the failure.

        """

    # pylint: disable=arguments-differ
    def describe_user_profile(
        self, userArn: str
    ) -> ClientDescribeUserProfileResponseTypeDef:
        """
        Describes a user in AWS CodeStar and the user attributes across all projects.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/DescribeUserProfile>`_

        **Request Syntax**
        ::

          response = client.describe_user_profile(
              userArn='string'
          )
        :type userArn: string
        :param userArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the user.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'userArn': 'string',
                'displayName': 'string',
                'emailAddress': 'string',
                'sshPublicKey': 'string',
                'createdTimestamp': datetime(2015, 1, 1),
                'lastModifiedTimestamp': datetime(2015, 1, 1)
            }
          **Response Structure**

          - *(dict) --*

            - **userArn** *(string) --*

              The Amazon Resource Name (ARN) of the user.

            - **displayName** *(string) --*

              The display name shown for the user in AWS CodeStar projects. For example, this could be set
              to both first and last name ("Mary Major") or a single name ("Mary"). The display name is
              also used to generate the initial icon associated with the user in AWS CodeStar projects. If
              spaces are included in the display name, the first character that appears after the space
              will be used as the second character in the user initial icon. The initial icon displays a
              maximum of two characters, so a display name with more than one space (for example "Mary Jane
              Major") would generate an initial icon using the first character and the first character
              after the space ("MJ", not "MM").

            - **emailAddress** *(string) --*

              The email address for the user. Optional.

            - **sshPublicKey** *(string) --*

              The SSH public key associated with the user. This SSH public key is associated with the user
              profile, and can be used in conjunction with the associated private key for access to project
              resources, such as Amazon EC2 instances, if a project owner grants remote access to those
              resources.

            - **createdTimestamp** *(datetime) --*

              The date and time when the user profile was created in AWS CodeStar, in timestamp format.

            - **lastModifiedTimestamp** *(datetime) --*

              The date and time when the user profile was last modified, in timestamp format.

        """

    # pylint: disable=arguments-differ
    def disassociate_team_member(self, projectId: str, userArn: str) -> Dict[str, Any]:
        """
        Removes a user from a project. Removing a user from a project also removes the IAM policies from
        that user that allowed access to the project and its resources. Disassociating a team member does
        not remove that user's profile from AWS CodeStar. It does not remove the user from IAM.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/DisassociateTeamMember>`_

        **Request Syntax**
        ::

          response = client.disassociate_team_member(
              projectId='string',
              userArn='string'
          )
        :type projectId: string
        :param projectId: **[REQUIRED]**

          The ID of the AWS CodeStar project from which you want to remove a team member.

        :type userArn: string
        :param userArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the IAM user or group whom you want to remove from the project.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {}
          **Response Structure**

          - *(dict) --*
        """

    # pylint: disable=arguments-differ
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> None:
        """
        Generate a presigned url given a client, its method, and arguments

        :type ClientMethod: string
        :param ClientMethod: The client method to presign for

        :type Params: dict
        :param Params: The parameters normally passed to
            ``ClientMethod``.

        :type ExpiresIn: int
        :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

        :type HttpMethod: string
        :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

        :returns: The presigned url
        """

    # pylint: disable=arguments-differ
    def get_paginator(self, operation_name: str) -> Paginator:
        """
        Create a paginator for an operation.

        :type operation_name: string
        :param operation_name: The operation name.  This is the same name
            as the method name on the client.  For example, if the
            method name is ``create_foo``, and you'd normally invoke the
            operation as ``client.create_foo(**kwargs)``, if the
            ``create_foo`` operation can be paginated, you can use the
            call ``client.get_paginator("create_foo")``.

        :raise OperationNotPageableError: Raised if the operation is not
            pageable.  You can use the ``client.can_paginate`` method to
            check if an operation is pageable.

        :rtype: L{botocore.paginate.Paginator}
        :return: A paginator object.
        """

    # pylint: disable=arguments-differ
    def get_waiter(self, waiter_name: str) -> Waiter:
        """
        Returns an object that can wait for some condition.

        :type waiter_name: str
        :param waiter_name: The name of the waiter to get. See the waiters
            section of the service docs for a list of available waiters.

        :returns: The specified waiter object.
        :rtype: botocore.waiter.Waiter
        """

    # pylint: disable=arguments-differ
    def list_projects(
        self, nextToken: str = None, maxResults: int = None
    ) -> ClientListProjectsResponseTypeDef:
        """
        Lists all projects in AWS CodeStar associated with your AWS account.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/ListProjects>`_

        **Request Syntax**
        ::

          response = client.list_projects(
              nextToken='string',
              maxResults=123
          )
        :type nextToken: string
        :param nextToken:

          The continuation token to be used to return the next set of results, if the results cannot be
          returned in one response.

        :type maxResults: integer
        :param maxResults:

          The maximum amount of data that can be contained in a single set of results.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'projects': [
                    {
                        'projectId': 'string',
                        'projectArn': 'string'
                    },
                ],
                'nextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **projects** *(list) --*

              A list of projects.

              - *(dict) --*

                Information about the metadata for a project.

                - **projectId** *(string) --*

                  The ID of the project.

                - **projectArn** *(string) --*

                  The Amazon Resource Name (ARN) of the project.

            - **nextToken** *(string) --*

              The continuation token to use when requesting the next set of results, if there are more
              results to be returned.

        """

    # pylint: disable=arguments-differ
    def list_resources(
        self, projectId: str, nextToken: str = None, maxResults: int = None
    ) -> ClientListResourcesResponseTypeDef:
        """
        Lists resources associated with a project in AWS CodeStar.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/ListResources>`_

        **Request Syntax**
        ::

          response = client.list_resources(
              projectId='string',
              nextToken='string',
              maxResults=123
          )
        :type projectId: string
        :param projectId: **[REQUIRED]**

          The ID of the project.

        :type nextToken: string
        :param nextToken:

          The continuation token for the next set of results, if the results cannot be returned in one
          response.

        :type maxResults: integer
        :param maxResults:

          The maximum amount of data that can be contained in a single set of results.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'resources': [
                    {
                        'id': 'string'
                    },
                ],
                'nextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **resources** *(list) --*

              An array of resources associated with the project.

              - *(dict) --*

                Information about a resource for a project.

                - **id** *(string) --*

                  The Amazon Resource Name (ARN) of the resource.

            - **nextToken** *(string) --*

              The continuation token to use when requesting the next set of results, if there are more
              results to be returned.

        """

    # pylint: disable=arguments-differ
    def list_tags_for_project(
        self, id: str, nextToken: str = None, maxResults: int = None
    ) -> ClientListTagsForProjectResponseTypeDef:
        """
        Gets the tags for a project.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/ListTagsForProject>`_

        **Request Syntax**
        ::

          response = client.list_tags_for_project(
              id='string',
              nextToken='string',
              maxResults=123
          )
        :type id: string
        :param id: **[REQUIRED]**

          The ID of the project to get tags for.

        :type nextToken: string
        :param nextToken:

          Reserved for future use.

        :type maxResults: integer
        :param maxResults:

          Reserved for future use.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'tags': {
                    'string': 'string'
                },
                'nextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **tags** *(dict) --*

              The tags for the project.

              - *(string) --*

                - *(string) --*

            - **nextToken** *(string) --*

              Reserved for future use.

        """

    # pylint: disable=arguments-differ
    def list_team_members(
        self, projectId: str, nextToken: str = None, maxResults: int = None
    ) -> ClientListTeamMembersResponseTypeDef:
        """
        Lists all team members associated with a project.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/ListTeamMembers>`_

        **Request Syntax**
        ::

          response = client.list_team_members(
              projectId='string',
              nextToken='string',
              maxResults=123
          )
        :type projectId: string
        :param projectId: **[REQUIRED]**

          The ID of the project for which you want to list team members.

        :type nextToken: string
        :param nextToken:

          The continuation token for the next set of results, if the results cannot be returned in one
          response.

        :type maxResults: integer
        :param maxResults:

          The maximum number of team members you want returned in a response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'teamMembers': [
                    {
                        'userArn': 'string',
                        'projectRole': 'string',
                        'remoteAccessAllowed': True|False
                    },
                ],
                'nextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **teamMembers** *(list) --*

              A list of team member objects for the project.

              - *(dict) --*

                Information about a team member in a project.

                - **userArn** *(string) --*

                  The Amazon Resource Name (ARN) of the user in IAM.

                - **projectRole** *(string) --*

                  The role assigned to the user in the project. Project roles have different levels of
                  access. For more information, see `Working with Teams
                  <http://docs.aws.amazon.com/codestar/latest/userguide/working-with-teams.html>`__ in the
                  *AWS CodeStar User Guide* .

                - **remoteAccessAllowed** *(boolean) --*

                  Whether the user is allowed to remotely access project resources using an SSH
                  public/private key pair.

            - **nextToken** *(string) --*

              The continuation token to use when requesting the next set of results, if there are more
              results to be returned.

        """

    # pylint: disable=arguments-differ
    def list_user_profiles(
        self, nextToken: str = None, maxResults: int = None
    ) -> ClientListUserProfilesResponseTypeDef:
        """
        Lists all the user profiles configured for your AWS account in AWS CodeStar.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/ListUserProfiles>`_

        **Request Syntax**
        ::

          response = client.list_user_profiles(
              nextToken='string',
              maxResults=123
          )
        :type nextToken: string
        :param nextToken:

          The continuation token for the next set of results, if the results cannot be returned in one
          response.

        :type maxResults: integer
        :param maxResults:

          The maximum number of results to return in a response.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'userProfiles': [
                    {
                        'userArn': 'string',
                        'displayName': 'string',
                        'emailAddress': 'string',
                        'sshPublicKey': 'string'
                    },
                ],
                'nextToken': 'string'
            }
          **Response Structure**

          - *(dict) --*

            - **userProfiles** *(list) --*

              All the user profiles configured in AWS CodeStar for an AWS account.

              - *(dict) --*

                Information about a user's profile in AWS CodeStar.

                - **userArn** *(string) --*

                  The Amazon Resource Name (ARN) of the user in IAM.

                - **displayName** *(string) --*

                  The display name of a user in AWS CodeStar. For example, this could be set to both first
                  and last name ("Mary Major") or a single name ("Mary"). The display name is also used to
                  generate the initial icon associated with the user in AWS CodeStar projects. If spaces
                  are included in the display name, the first character that appears after the space will
                  be used as the second character in the user initial icon. The initial icon displays a
                  maximum of two characters, so a display name with more than one space (for example "Mary
                  Jane Major") would generate an initial icon using the first character and the first
                  character after the space ("MJ", not "MM").

                - **emailAddress** *(string) --*

                  The email address associated with the user.

                - **sshPublicKey** *(string) --*

                  The SSH public key associated with the user in AWS CodeStar. If a project owner allows
                  the user remote access to project resources, this public key will be used along with the
                  user's private key for SSH access.

            - **nextToken** *(string) --*

              The continuation token to use when requesting the next set of results, if there are more
              results to be returned.

        """

    # pylint: disable=arguments-differ
    def tag_project(
        self, id: str, tags: Dict[str, str]
    ) -> ClientTagProjectResponseTypeDef:
        """
        Adds tags to a project.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/TagProject>`_

        **Request Syntax**
        ::

          response = client.tag_project(
              id='string',
              tags={
                  'string': 'string'
              }
          )
        :type id: string
        :param id: **[REQUIRED]**

          The ID of the project you want to add a tag to.

        :type tags: dict
        :param tags: **[REQUIRED]**

          The tags you want to add to the project.

          - *(string) --*

            - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'tags': {
                    'string': 'string'
                }
            }
          **Response Structure**

          - *(dict) --*

            - **tags** *(dict) --*

              The tags for the project.

              - *(string) --*

                - *(string) --*

        """

    # pylint: disable=arguments-differ
    def untag_project(self, id: str, tags: List[str]) -> Dict[str, Any]:
        """
        Removes tags from a project.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/UntagProject>`_

        **Request Syntax**
        ::

          response = client.untag_project(
              id='string',
              tags=[
                  'string',
              ]
          )
        :type id: string
        :param id: **[REQUIRED]**

          The ID of the project to remove tags from.

        :type tags: list
        :param tags: **[REQUIRED]**

          The tags to remove from the project.

          - *(string) --*

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {}
          **Response Structure**

          - *(dict) --*
        """

    # pylint: disable=arguments-differ
    def update_project(
        self, id: str, name: str = None, description: str = None
    ) -> Dict[str, Any]:
        """
        Updates a project in AWS CodeStar.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/UpdateProject>`_

        **Request Syntax**
        ::

          response = client.update_project(
              id='string',
              name='string',
              description='string'
          )
        :type id: string
        :param id: **[REQUIRED]**

          The ID of the project you want to update.

        :type name: string
        :param name:

          The name of the project you want to update.

        :type description: string
        :param description:

          The description of the project, if any.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {}
          **Response Structure**

          - *(dict) --*
        """

    # pylint: disable=arguments-differ
    def update_team_member(
        self,
        projectId: str,
        userArn: str,
        projectRole: str = None,
        remoteAccessAllowed: bool = None,
    ) -> ClientUpdateTeamMemberResponseTypeDef:
        """
        Updates a team member's attributes in an AWS CodeStar project. For example, you can change a team
        member's role in the project, or change whether they have remote access to project resources.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/UpdateTeamMember>`_

        **Request Syntax**
        ::

          response = client.update_team_member(
              projectId='string',
              userArn='string',
              projectRole='string',
              remoteAccessAllowed=True|False
          )
        :type projectId: string
        :param projectId: **[REQUIRED]**

          The ID of the project.

        :type userArn: string
        :param userArn: **[REQUIRED]**

          The Amazon Resource Name (ARN) of the user for whom you want to change team membership attributes.

        :type projectRole: string
        :param projectRole:

          The role assigned to the user in the project. Project roles have different levels of access. For
          more information, see `Working with Teams
          <http://docs.aws.amazon.com/codestar/latest/userguide/working-with-teams.html>`__ in the *AWS
          CodeStar User Guide* .

        :type remoteAccessAllowed: boolean
        :param remoteAccessAllowed:

          Whether a team member is allowed to remotely access project resources using the SSH public key
          associated with the user's profile. Even if this is set to True, the user must associate a public
          key with their profile before the user can access resources.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'userArn': 'string',
                'projectRole': 'string',
                'remoteAccessAllowed': True|False
            }
          **Response Structure**

          - *(dict) --*

            - **userArn** *(string) --*

              The Amazon Resource Name (ARN) of the user whose team membership attributes were updated.

            - **projectRole** *(string) --*

              The project role granted to the user.

            - **remoteAccessAllowed** *(boolean) --*

              Whether a team member is allowed to remotely access project resources using the SSH public
              key associated with the user's profile.

        """

    # pylint: disable=arguments-differ
    def update_user_profile(
        self,
        userArn: str,
        displayName: str = None,
        emailAddress: str = None,
        sshPublicKey: str = None,
    ) -> ClientUpdateUserProfileResponseTypeDef:
        """
        Updates a user's profile in AWS CodeStar. The user profile is not project-specific. Information in
        the user profile is displayed wherever the user's information appears to other users in AWS
        CodeStar.

        See also: `AWS API Documentation
        <https://docs.aws.amazon.com/goto/WebAPI/codestar-2017-04-19/UpdateUserProfile>`_

        **Request Syntax**
        ::

          response = client.update_user_profile(
              userArn='string',
              displayName='string',
              emailAddress='string',
              sshPublicKey='string'
          )
        :type userArn: string
        :param userArn: **[REQUIRED]**

          The name that will be displayed as the friendly name for the user in AWS CodeStar.

        :type displayName: string
        :param displayName:

          The name that is displayed as the friendly name for the user in AWS CodeStar.

        :type emailAddress: string
        :param emailAddress:

          The email address that is displayed as part of the user's profile in AWS CodeStar.

        :type sshPublicKey: string
        :param sshPublicKey:

          The SSH public key associated with the user in AWS CodeStar. If a project owner allows the user
          remote access to project resources, this public key will be used along with the user's private
          key for SSH access.

        :rtype: dict
        :returns:

          **Response Syntax**

          ::

            {
                'userArn': 'string',
                'displayName': 'string',
                'emailAddress': 'string',
                'sshPublicKey': 'string',
                'createdTimestamp': datetime(2015, 1, 1),
                'lastModifiedTimestamp': datetime(2015, 1, 1)
            }
          **Response Structure**

          - *(dict) --*

            - **userArn** *(string) --*

              The Amazon Resource Name (ARN) of the user in IAM.

            - **displayName** *(string) --*

              The name that is displayed as the friendly name for the user in AWS CodeStar.

            - **emailAddress** *(string) --*

              The email address that is displayed as part of the user's profile in AWS CodeStar.

            - **sshPublicKey** *(string) --*

              The SSH public key associated with the user in AWS CodeStar. This is the public portion of
              the public/private keypair the user can use to access project resources if a project owner
              allows the user remote access to those resources.

            - **createdTimestamp** *(datetime) --*

              The date the user profile was created, in timestamp format.

            - **lastModifiedTimestamp** *(datetime) --*

              The date the user profile was last modified, in timestamp format.

        """



"Main interface for codestar type defs"
from __future__ import annotations

from datetime import datetime
from typing import Dict, List
from typing_extensions import TypedDict


_ClientAssociateTeamMemberResponseTypeDef = TypedDict(
    "_ClientAssociateTeamMemberResponseTypeDef",
    {"clientRequestToken": str},
    total=False,
)


class ClientAssociateTeamMemberResponseTypeDef(
    _ClientAssociateTeamMemberResponseTypeDef
):
    """
    Type definition for `ClientAssociateTeamMember` `Response`

    - **clientRequestToken** *(string) --*

      The user- or system-generated token from the initial request that can be used to repeat the
      request.
    """


_ClientCreateProjectResponseTypeDef = TypedDict(
    "_ClientCreateProjectResponseTypeDef",
    {"id": str, "arn": str, "clientRequestToken": str, "projectTemplateId": str},
    total=False,
)


class ClientCreateProjectResponseTypeDef(_ClientCreateProjectResponseTypeDef):
    """
    Type definition for `ClientCreateProject` `Response`

    - **id** *(string) --*

      The ID of the project.

    - **arn** *(string) --*

      The Amazon Resource Name (ARN) of the created project.

    - **clientRequestToken** *(string) --*

      A user- or system-generated token that identifies the entity that requested project creation.

    - **projectTemplateId** *(string) --*

      Reserved for future use.
    """


_ClientCreateProjectsourceCodedestinationcodeCommitTypeDef = TypedDict(
    "_ClientCreateProjectsourceCodedestinationcodeCommitTypeDef", {"name": str}
)


class ClientCreateProjectsourceCodedestinationcodeCommitTypeDef(
    _ClientCreateProjectsourceCodedestinationcodeCommitTypeDef
):
    """
    Type definition for `ClientCreateProjectsourceCodedestination` `codeCommit`

    Information about the AWS CodeCommit repository to be created in AWS CodeStar. This is
    where the source code files provided with the project request will be uploaded after
    project creation.

    - **name** *(string) --* **[REQUIRED]**

      The name of the AWS CodeCommit repository to be created in AWS CodeStar.
    """


_RequiredClientCreateProjectsourceCodedestinationgitHubTypeDef = TypedDict(
    "_RequiredClientCreateProjectsourceCodedestinationgitHubTypeDef",
    {
        "name": str,
        "type": str,
        "owner": str,
        "privateRepository": bool,
        "issuesEnabled": bool,
        "token": str,
    },
)
_OptionalClientCreateProjectsourceCodedestinationgitHubTypeDef = TypedDict(
    "_OptionalClientCreateProjectsourceCodedestinationgitHubTypeDef",
    {"description": str},
    total=False,
)


class ClientCreateProjectsourceCodedestinationgitHubTypeDef(
    _RequiredClientCreateProjectsourceCodedestinationgitHubTypeDef,
    _OptionalClientCreateProjectsourceCodedestinationgitHubTypeDef,
):
    """
    Type definition for `ClientCreateProjectsourceCodedestination` `gitHub`

    Information about the GitHub repository to be created in AWS CodeStar. This is where the
    source code files provided with the project request will be uploaded after project creation.

    - **name** *(string) --* **[REQUIRED]**

      Name of the GitHub repository to be created in AWS CodeStar.

    - **description** *(string) --*

      Description for the GitHub repository to be created in AWS CodeStar. This description
      displays in GitHub after the repository is created.

    - **type** *(string) --* **[REQUIRED]**

      The type of GitHub repository to be created in AWS CodeStar. Valid values are User or
      Organization.

    - **owner** *(string) --* **[REQUIRED]**

      The GitHub username for the owner of the GitHub repository to be created in AWS CodeStar.
      If this repository should be owned by a GitHub organization, provide its name.

    - **privateRepository** *(boolean) --* **[REQUIRED]**

      Whether the GitHub repository is to be a private repository.

    - **issuesEnabled** *(boolean) --* **[REQUIRED]**

      Whether to enable issues for the GitHub repository.

    - **token** *(string) --* **[REQUIRED]**

      The GitHub user's personal access token for the GitHub repository.
    """


_ClientCreateProjectsourceCodedestinationTypeDef = TypedDict(
    "_ClientCreateProjectsourceCodedestinationTypeDef",
    {
        "codeCommit": ClientCreateProjectsourceCodedestinationcodeCommitTypeDef,
        "gitHub": ClientCreateProjectsourceCodedestinationgitHubTypeDef,
    },
    total=False,
)


class ClientCreateProjectsourceCodedestinationTypeDef(
    _ClientCreateProjectsourceCodedestinationTypeDef
):
    """
    Type definition for `ClientCreateProjectsourceCode` `destination`

    The repository to be created in AWS CodeStar. Valid values are AWS CodeCommit or GitHub.
    After AWS CodeStar provisions the new repository, the source code files provided with the
    project request are placed in the repository.

    - **codeCommit** *(dict) --*

      Information about the AWS CodeCommit repository to be created in AWS CodeStar. This is
      where the source code files provided with the project request will be uploaded after
      project creation.

      - **name** *(string) --* **[REQUIRED]**

        The name of the AWS CodeCommit repository to be created in AWS CodeStar.

    - **gitHub** *(dict) --*

      Information about the GitHub repository to be created in AWS CodeStar. This is where the
      source code files provided with the project request will be uploaded after project creation.

      - **name** *(string) --* **[REQUIRED]**

        Name of the GitHub repository to be created in AWS CodeStar.

      - **description** *(string) --*

        Description for the GitHub repository to be created in AWS CodeStar. This description
        displays in GitHub after the repository is created.

      - **type** *(string) --* **[REQUIRED]**

        The type of GitHub repository to be created in AWS CodeStar. Valid values are User or
        Organization.

      - **owner** *(string) --* **[REQUIRED]**

        The GitHub username for the owner of the GitHub repository to be created in AWS CodeStar.
        If this repository should be owned by a GitHub organization, provide its name.

      - **privateRepository** *(boolean) --* **[REQUIRED]**

        Whether the GitHub repository is to be a private repository.

      - **issuesEnabled** *(boolean) --* **[REQUIRED]**

        Whether to enable issues for the GitHub repository.

      - **token** *(string) --* **[REQUIRED]**

        The GitHub user's personal access token for the GitHub repository.
    """


_ClientCreateProjectsourceCodesources3TypeDef = TypedDict(
    "_ClientCreateProjectsourceCodesources3TypeDef",
    {"bucketName": str, "bucketKey": str},
    total=False,
)


class ClientCreateProjectsourceCodesources3TypeDef(
    _ClientCreateProjectsourceCodesources3TypeDef
):
    """
    Type definition for `ClientCreateProjectsourceCodesource` `s3`

    Information about the Amazon S3 location where the source code files provided with the
    project request are stored.

    - **bucketName** *(string) --*

      The Amazon S3 bucket name where the source code files provided with the project request
      are stored.

    - **bucketKey** *(string) --*

      The Amazon S3 object key where the source code files provided with the project request
      are stored.
    """


_ClientCreateProjectsourceCodesourceTypeDef = TypedDict(
    "_ClientCreateProjectsourceCodesourceTypeDef",
    {"s3": ClientCreateProjectsourceCodesources3TypeDef},
)


class ClientCreateProjectsourceCodesourceTypeDef(
    _ClientCreateProjectsourceCodesourceTypeDef
):
    """
    Type definition for `ClientCreateProjectsourceCode` `source`

    The location where the source code files provided with the project request are stored. AWS
    CodeStar retrieves the files during project creation.

    - **s3** *(dict) --* **[REQUIRED]**

      Information about the Amazon S3 location where the source code files provided with the
      project request are stored.

      - **bucketName** *(string) --*

        The Amazon S3 bucket name where the source code files provided with the project request
        are stored.

      - **bucketKey** *(string) --*

        The Amazon S3 object key where the source code files provided with the project request
        are stored.
    """


_ClientCreateProjectsourceCodeTypeDef = TypedDict(
    "_ClientCreateProjectsourceCodeTypeDef",
    {
        "source": ClientCreateProjectsourceCodesourceTypeDef,
        "destination": ClientCreateProjectsourceCodedestinationTypeDef,
    },
)


class ClientCreateProjectsourceCodeTypeDef(_ClientCreateProjectsourceCodeTypeDef):
    """
    Type definition for `ClientCreateProject` `sourceCode`

    Location and destination information about the source code files provided with the project
    request. The source code is uploaded to the new project source repository after project
    creation.

    - **source** *(dict) --* **[REQUIRED]**

      The location where the source code files provided with the project request are stored. AWS
      CodeStar retrieves the files during project creation.

      - **s3** *(dict) --* **[REQUIRED]**

        Information about the Amazon S3 location where the source code files provided with the
        project request are stored.

        - **bucketName** *(string) --*

          The Amazon S3 bucket name where the source code files provided with the project request
          are stored.

        - **bucketKey** *(string) --*

          The Amazon S3 object key where the source code files provided with the project request
          are stored.

    - **destination** *(dict) --* **[REQUIRED]**

      The repository to be created in AWS CodeStar. Valid values are AWS CodeCommit or GitHub.
      After AWS CodeStar provisions the new repository, the source code files provided with the
      project request are placed in the repository.

      - **codeCommit** *(dict) --*

        Information about the AWS CodeCommit repository to be created in AWS CodeStar. This is
        where the source code files provided with the project request will be uploaded after
        project creation.

        - **name** *(string) --* **[REQUIRED]**

          The name of the AWS CodeCommit repository to be created in AWS CodeStar.

      - **gitHub** *(dict) --*

        Information about the GitHub repository to be created in AWS CodeStar. This is where the
        source code files provided with the project request will be uploaded after project creation.

        - **name** *(string) --* **[REQUIRED]**

          Name of the GitHub repository to be created in AWS CodeStar.

        - **description** *(string) --*

          Description for the GitHub repository to be created in AWS CodeStar. This description
          displays in GitHub after the repository is created.

        - **type** *(string) --* **[REQUIRED]**

          The type of GitHub repository to be created in AWS CodeStar. Valid values are User or
          Organization.

        - **owner** *(string) --* **[REQUIRED]**

          The GitHub username for the owner of the GitHub repository to be created in AWS CodeStar.
          If this repository should be owned by a GitHub organization, provide its name.

        - **privateRepository** *(boolean) --* **[REQUIRED]**

          Whether the GitHub repository is to be a private repository.

        - **issuesEnabled** *(boolean) --* **[REQUIRED]**

          Whether to enable issues for the GitHub repository.

        - **token** *(string) --* **[REQUIRED]**

          The GitHub user's personal access token for the GitHub repository.
    """


_ClientCreateProjecttoolchainsources3TypeDef = TypedDict(
    "_ClientCreateProjecttoolchainsources3TypeDef",
    {"bucketName": str, "bucketKey": str},
    total=False,
)


class ClientCreateProjecttoolchainsources3TypeDef(
    _ClientCreateProjecttoolchainsources3TypeDef
):
    """
    Type definition for `ClientCreateProjecttoolchainsource` `s3`

    The Amazon S3 bucket where the toolchain template file provided with the project request is
    stored.

    - **bucketName** *(string) --*

      The Amazon S3 bucket name where the source code files provided with the project request are
      stored.

    - **bucketKey** *(string) --*

      The Amazon S3 object key where the source code files provided with the project request are
      stored.
    """


_ClientCreateProjecttoolchainsourceTypeDef = TypedDict(
    "_ClientCreateProjecttoolchainsourceTypeDef",
    {"s3": ClientCreateProjecttoolchainsources3TypeDef},
)


class ClientCreateProjecttoolchainsourceTypeDef(
    _ClientCreateProjecttoolchainsourceTypeDef
):
    """
    Type definition for `ClientCreateProjecttoolchain` `source`

    The Amazon S3 location where the toolchain template file provided with the project request is
    stored. AWS CodeStar retrieves the file during project creation.

    - **s3** *(dict) --* **[REQUIRED]**

      The Amazon S3 bucket where the toolchain template file provided with the project request is
      stored.

      - **bucketName** *(string) --*

        The Amazon S3 bucket name where the source code files provided with the project request are
        stored.

      - **bucketKey** *(string) --*

        The Amazon S3 object key where the source code files provided with the project request are
        stored.
    """


_RequiredClientCreateProjecttoolchainTypeDef = TypedDict(
    "_RequiredClientCreateProjecttoolchainTypeDef",
    {"source": ClientCreateProjecttoolchainsourceTypeDef},
)
_OptionalClientCreateProjecttoolchainTypeDef = TypedDict(
    "_OptionalClientCreateProjecttoolchainTypeDef",
    {"roleArn": str, "stackParameters": Dict[str, str]},
    total=False,
)


class ClientCreateProjecttoolchainTypeDef(
    _RequiredClientCreateProjecttoolchainTypeDef,
    _OptionalClientCreateProjecttoolchainTypeDef,
):
    """
    Type definition for `ClientCreateProject` `toolchain`

    The name of the toolchain template file submitted with the project request. If this parameter is
    specified, the request must also include the sourceCode parameter.

    - **source** *(dict) --* **[REQUIRED]**

      The Amazon S3 location where the toolchain template file provided with the project request is
      stored. AWS CodeStar retrieves the file during project creation.

      - **s3** *(dict) --* **[REQUIRED]**

        The Amazon S3 bucket where the toolchain template file provided with the project request is
        stored.

        - **bucketName** *(string) --*

          The Amazon S3 bucket name where the source code files provided with the project request are
          stored.

        - **bucketKey** *(string) --*

          The Amazon S3 object key where the source code files provided with the project request are
          stored.

    - **roleArn** *(string) --*

      The service role ARN for AWS CodeStar to use for the toolchain template during stack
      provisioning.

    - **stackParameters** *(dict) --*

      The list of parameter overrides to be passed into the toolchain template during stack
      provisioning, if any.

      - *(string) --*

        - *(string) --*
    """


_ClientCreateUserProfileResponseTypeDef = TypedDict(
    "_ClientCreateUserProfileResponseTypeDef",
    {
        "userArn": str,
        "displayName": str,
        "emailAddress": str,
        "sshPublicKey": str,
        "createdTimestamp": datetime,
        "lastModifiedTimestamp": datetime,
    },
    total=False,
)


class ClientCreateUserProfileResponseTypeDef(_ClientCreateUserProfileResponseTypeDef):
    """
    Type definition for `ClientCreateUserProfile` `Response`

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user in IAM.

    - **displayName** *(string) --*

      The name that is displayed as the friendly name for the user in AWS CodeStar.

    - **emailAddress** *(string) --*

      The email address that is displayed as part of the user's profile in AWS CodeStar.

    - **sshPublicKey** *(string) --*

      The SSH public key associated with the user in AWS CodeStar. This is the public portion of
      the public/private keypair the user can use to access project resources if a project owner
      allows the user remote access to those resources.

    - **createdTimestamp** *(datetime) --*

      The date the user profile was created, in timestamp format.

    - **lastModifiedTimestamp** *(datetime) --*

      The date the user profile was last modified, in timestamp format.
    """


_ClientDeleteProjectResponseTypeDef = TypedDict(
    "_ClientDeleteProjectResponseTypeDef",
    {"stackId": str, "projectArn": str},
    total=False,
)


class ClientDeleteProjectResponseTypeDef(_ClientDeleteProjectResponseTypeDef):
    """
    Type definition for `ClientDeleteProject` `Response`

    - **stackId** *(string) --*

      The ID of the primary stack in AWS CloudFormation that will be deleted as part of deleting
      the project and its resources.

    - **projectArn** *(string) --*

      The Amazon Resource Name (ARN) of the deleted project.
    """


_ClientDeleteUserProfileResponseTypeDef = TypedDict(
    "_ClientDeleteUserProfileResponseTypeDef", {"userArn": str}, total=False
)


class ClientDeleteUserProfileResponseTypeDef(_ClientDeleteUserProfileResponseTypeDef):
    """
    Type definition for `ClientDeleteUserProfile` `Response`

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user deleted from AWS CodeStar.
    """


_ClientDescribeProjectResponsestatusTypeDef = TypedDict(
    "_ClientDescribeProjectResponsestatusTypeDef",
    {"state": str, "reason": str},
    total=False,
)


class ClientDescribeProjectResponsestatusTypeDef(
    _ClientDescribeProjectResponsestatusTypeDef
):
    """
    Type definition for `ClientDescribeProjectResponse` `status`

    The project creation or deletion status.

    - **state** *(string) --*

      The phase of completion for a project creation or deletion.

    - **reason** *(string) --*

      In the case of a project creation or deletion failure, a reason for the failure.
    """


_ClientDescribeProjectResponseTypeDef = TypedDict(
    "_ClientDescribeProjectResponseTypeDef",
    {
        "name": str,
        "id": str,
        "arn": str,
        "description": str,
        "clientRequestToken": str,
        "createdTimeStamp": datetime,
        "stackId": str,
        "projectTemplateId": str,
        "status": ClientDescribeProjectResponsestatusTypeDef,
    },
    total=False,
)


class ClientDescribeProjectResponseTypeDef(_ClientDescribeProjectResponseTypeDef):
    """
    Type definition for `ClientDescribeProject` `Response`

    - **name** *(string) --*

      The display name for the project.

    - **id** *(string) --*

      The ID of the project.

    - **arn** *(string) --*

      The Amazon Resource Name (ARN) for the project.

    - **description** *(string) --*

      The description of the project, if any.

    - **clientRequestToken** *(string) --*

      A user- or system-generated token that identifies the entity that requested project creation.

    - **createdTimeStamp** *(datetime) --*

      The date and time the project was created, in timestamp format.

    - **stackId** *(string) --*

      The ID of the primary stack in AWS CloudFormation used to generate resources for the project.

    - **projectTemplateId** *(string) --*

      The ID for the AWS CodeStar project template used to create the project.

    - **status** *(dict) --*

      The project creation or deletion status.

      - **state** *(string) --*

        The phase of completion for a project creation or deletion.

      - **reason** *(string) --*

        In the case of a project creation or deletion failure, a reason for the failure.
    """


_ClientDescribeUserProfileResponseTypeDef = TypedDict(
    "_ClientDescribeUserProfileResponseTypeDef",
    {
        "userArn": str,
        "displayName": str,
        "emailAddress": str,
        "sshPublicKey": str,
        "createdTimestamp": datetime,
        "lastModifiedTimestamp": datetime,
    },
    total=False,
)


class ClientDescribeUserProfileResponseTypeDef(
    _ClientDescribeUserProfileResponseTypeDef
):
    """
    Type definition for `ClientDescribeUserProfile` `Response`

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user.

    - **displayName** *(string) --*

      The display name shown for the user in AWS CodeStar projects. For example, this could be set
      to both first and last name ("Mary Major") or a single name ("Mary"). The display name is
      also used to generate the initial icon associated with the user in AWS CodeStar projects. If
      spaces are included in the display name, the first character that appears after the space
      will be used as the second character in the user initial icon. The initial icon displays a
      maximum of two characters, so a display name with more than one space (for example "Mary Jane
      Major") would generate an initial icon using the first character and the first character
      after the space ("MJ", not "MM").

    - **emailAddress** *(string) --*

      The email address for the user. Optional.

    - **sshPublicKey** *(string) --*

      The SSH public key associated with the user. This SSH public key is associated with the user
      profile, and can be used in conjunction with the associated private key for access to project
      resources, such as Amazon EC2 instances, if a project owner grants remote access to those
      resources.

    - **createdTimestamp** *(datetime) --*

      The date and time when the user profile was created in AWS CodeStar, in timestamp format.

    - **lastModifiedTimestamp** *(datetime) --*

      The date and time when the user profile was last modified, in timestamp format.
    """


_ClientListProjectsResponseprojectsTypeDef = TypedDict(
    "_ClientListProjectsResponseprojectsTypeDef",
    {"projectId": str, "projectArn": str},
    total=False,
)


class ClientListProjectsResponseprojectsTypeDef(
    _ClientListProjectsResponseprojectsTypeDef
):
    """
    Type definition for `ClientListProjectsResponse` `projects`

    Information about the metadata for a project.

    - **projectId** *(string) --*

      The ID of the project.

    - **projectArn** *(string) --*

      The Amazon Resource Name (ARN) of the project.
    """


_ClientListProjectsResponseTypeDef = TypedDict(
    "_ClientListProjectsResponseTypeDef",
    {"projects": List[ClientListProjectsResponseprojectsTypeDef], "nextToken": str},
    total=False,
)


class ClientListProjectsResponseTypeDef(_ClientListProjectsResponseTypeDef):
    """
    Type definition for `ClientListProjects` `Response`

    - **projects** *(list) --*

      A list of projects.

      - *(dict) --*

        Information about the metadata for a project.

        - **projectId** *(string) --*

          The ID of the project.

        - **projectArn** *(string) --*

          The Amazon Resource Name (ARN) of the project.

    - **nextToken** *(string) --*

      The continuation token to use when requesting the next set of results, if there are more
      results to be returned.
    """


_ClientListResourcesResponseresourcesTypeDef = TypedDict(
    "_ClientListResourcesResponseresourcesTypeDef", {"id": str}, total=False
)


class ClientListResourcesResponseresourcesTypeDef(
    _ClientListResourcesResponseresourcesTypeDef
):
    """
    Type definition for `ClientListResourcesResponse` `resources`

    Information about a resource for a project.

    - **id** *(string) --*

      The Amazon Resource Name (ARN) of the resource.
    """


_ClientListResourcesResponseTypeDef = TypedDict(
    "_ClientListResourcesResponseTypeDef",
    {"resources": List[ClientListResourcesResponseresourcesTypeDef], "nextToken": str},
    total=False,
)


class ClientListResourcesResponseTypeDef(_ClientListResourcesResponseTypeDef):
    """
    Type definition for `ClientListResources` `Response`

    - **resources** *(list) --*

      An array of resources associated with the project.

      - *(dict) --*

        Information about a resource for a project.

        - **id** *(string) --*

          The Amazon Resource Name (ARN) of the resource.

    - **nextToken** *(string) --*

      The continuation token to use when requesting the next set of results, if there are more
      results to be returned.
    """


_ClientListTagsForProjectResponseTypeDef = TypedDict(
    "_ClientListTagsForProjectResponseTypeDef",
    {"tags": Dict[str, str], "nextToken": str},
    total=False,
)


class ClientListTagsForProjectResponseTypeDef(_ClientListTagsForProjectResponseTypeDef):
    """
    Type definition for `ClientListTagsForProject` `Response`

    - **tags** *(dict) --*

      The tags for the project.

      - *(string) --*

        - *(string) --*

    - **nextToken** *(string) --*

      Reserved for future use.
    """


_ClientListTeamMembersResponseteamMembersTypeDef = TypedDict(
    "_ClientListTeamMembersResponseteamMembersTypeDef",
    {"userArn": str, "projectRole": str, "remoteAccessAllowed": bool},
    total=False,
)


class ClientListTeamMembersResponseteamMembersTypeDef(
    _ClientListTeamMembersResponseteamMembersTypeDef
):
    """
    Type definition for `ClientListTeamMembersResponse` `teamMembers`

    Information about a team member in a project.

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user in IAM.

    - **projectRole** *(string) --*

      The role assigned to the user in the project. Project roles have different levels of
      access. For more information, see `Working with Teams
      <http://docs.aws.amazon.com/codestar/latest/userguide/working-with-teams.html>`__ in the
      *AWS CodeStar User Guide* .

    - **remoteAccessAllowed** *(boolean) --*

      Whether the user is allowed to remotely access project resources using an SSH
      public/private key pair.
    """


_ClientListTeamMembersResponseTypeDef = TypedDict(
    "_ClientListTeamMembersResponseTypeDef",
    {
        "teamMembers": List[ClientListTeamMembersResponseteamMembersTypeDef],
        "nextToken": str,
    },
    total=False,
)


class ClientListTeamMembersResponseTypeDef(_ClientListTeamMembersResponseTypeDef):
    """
    Type definition for `ClientListTeamMembers` `Response`

    - **teamMembers** *(list) --*

      A list of team member objects for the project.

      - *(dict) --*

        Information about a team member in a project.

        - **userArn** *(string) --*

          The Amazon Resource Name (ARN) of the user in IAM.

        - **projectRole** *(string) --*

          The role assigned to the user in the project. Project roles have different levels of
          access. For more information, see `Working with Teams
          <http://docs.aws.amazon.com/codestar/latest/userguide/working-with-teams.html>`__ in the
          *AWS CodeStar User Guide* .

        - **remoteAccessAllowed** *(boolean) --*

          Whether the user is allowed to remotely access project resources using an SSH
          public/private key pair.

    - **nextToken** *(string) --*

      The continuation token to use when requesting the next set of results, if there are more
      results to be returned.
    """


_ClientListUserProfilesResponseuserProfilesTypeDef = TypedDict(
    "_ClientListUserProfilesResponseuserProfilesTypeDef",
    {"userArn": str, "displayName": str, "emailAddress": str, "sshPublicKey": str},
    total=False,
)


class ClientListUserProfilesResponseuserProfilesTypeDef(
    _ClientListUserProfilesResponseuserProfilesTypeDef
):
    """
    Type definition for `ClientListUserProfilesResponse` `userProfiles`

    Information about a user's profile in AWS CodeStar.

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user in IAM.

    - **displayName** *(string) --*

      The display name of a user in AWS CodeStar. For example, this could be set to both first
      and last name ("Mary Major") or a single name ("Mary"). The display name is also used to
      generate the initial icon associated with the user in AWS CodeStar projects. If spaces
      are included in the display name, the first character that appears after the space will
      be used as the second character in the user initial icon. The initial icon displays a
      maximum of two characters, so a display name with more than one space (for example "Mary
      Jane Major") would generate an initial icon using the first character and the first
      character after the space ("MJ", not "MM").

    - **emailAddress** *(string) --*

      The email address associated with the user.

    - **sshPublicKey** *(string) --*

      The SSH public key associated with the user in AWS CodeStar. If a project owner allows
      the user remote access to project resources, this public key will be used along with the
      user's private key for SSH access.
    """


_ClientListUserProfilesResponseTypeDef = TypedDict(
    "_ClientListUserProfilesResponseTypeDef",
    {
        "userProfiles": List[ClientListUserProfilesResponseuserProfilesTypeDef],
        "nextToken": str,
    },
    total=False,
)


class ClientListUserProfilesResponseTypeDef(_ClientListUserProfilesResponseTypeDef):
    """
    Type definition for `ClientListUserProfiles` `Response`

    - **userProfiles** *(list) --*

      All the user profiles configured in AWS CodeStar for an AWS account.

      - *(dict) --*

        Information about a user's profile in AWS CodeStar.

        - **userArn** *(string) --*

          The Amazon Resource Name (ARN) of the user in IAM.

        - **displayName** *(string) --*

          The display name of a user in AWS CodeStar. For example, this could be set to both first
          and last name ("Mary Major") or a single name ("Mary"). The display name is also used to
          generate the initial icon associated with the user in AWS CodeStar projects. If spaces
          are included in the display name, the first character that appears after the space will
          be used as the second character in the user initial icon. The initial icon displays a
          maximum of two characters, so a display name with more than one space (for example "Mary
          Jane Major") would generate an initial icon using the first character and the first
          character after the space ("MJ", not "MM").

        - **emailAddress** *(string) --*

          The email address associated with the user.

        - **sshPublicKey** *(string) --*

          The SSH public key associated with the user in AWS CodeStar. If a project owner allows
          the user remote access to project resources, this public key will be used along with the
          user's private key for SSH access.

    - **nextToken** *(string) --*

      The continuation token to use when requesting the next set of results, if there are more
      results to be returned.
    """


_ClientTagProjectResponseTypeDef = TypedDict(
    "_ClientTagProjectResponseTypeDef", {"tags": Dict[str, str]}, total=False
)


class ClientTagProjectResponseTypeDef(_ClientTagProjectResponseTypeDef):
    """
    Type definition for `ClientTagProject` `Response`

    - **tags** *(dict) --*

      The tags for the project.

      - *(string) --*

        - *(string) --*
    """


_ClientUpdateTeamMemberResponseTypeDef = TypedDict(
    "_ClientUpdateTeamMemberResponseTypeDef",
    {"userArn": str, "projectRole": str, "remoteAccessAllowed": bool},
    total=False,
)


class ClientUpdateTeamMemberResponseTypeDef(_ClientUpdateTeamMemberResponseTypeDef):
    """
    Type definition for `ClientUpdateTeamMember` `Response`

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user whose team membership attributes were updated.

    - **projectRole** *(string) --*

      The project role granted to the user.

    - **remoteAccessAllowed** *(boolean) --*

      Whether a team member is allowed to remotely access project resources using the SSH public
      key associated with the user's profile.
    """


_ClientUpdateUserProfileResponseTypeDef = TypedDict(
    "_ClientUpdateUserProfileResponseTypeDef",
    {
        "userArn": str,
        "displayName": str,
        "emailAddress": str,
        "sshPublicKey": str,
        "createdTimestamp": datetime,
        "lastModifiedTimestamp": datetime,
    },
    total=False,
)


class ClientUpdateUserProfileResponseTypeDef(_ClientUpdateUserProfileResponseTypeDef):
    """
    Type definition for `ClientUpdateUserProfile` `Response`

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user in IAM.

    - **displayName** *(string) --*

      The name that is displayed as the friendly name for the user in AWS CodeStar.

    - **emailAddress** *(string) --*

      The email address that is displayed as part of the user's profile in AWS CodeStar.

    - **sshPublicKey** *(string) --*

      The SSH public key associated with the user in AWS CodeStar. This is the public portion of
      the public/private keypair the user can use to access project resources if a project owner
      allows the user remote access to those resources.

    - **createdTimestamp** *(datetime) --*

      The date the user profile was created, in timestamp format.

    - **lastModifiedTimestamp** *(datetime) --*

      The date the user profile was last modified, in timestamp format.
    """


_ListProjectsPaginatePaginationConfigTypeDef = TypedDict(
    "_ListProjectsPaginatePaginationConfigTypeDef",
    {"MaxItems": int, "PageSize": int, "StartingToken": str},
    total=False,
)


class ListProjectsPaginatePaginationConfigTypeDef(
    _ListProjectsPaginatePaginationConfigTypeDef
):
    """
    Type definition for `ListProjectsPaginate` `PaginationConfig`

    A dictionary that provides parameters to control pagination.

    - **MaxItems** *(integer) --*

      The total number of items to return. If the total number of items available is more than the
      value specified in max-items then a ``NextToken`` will be provided in the output that you can
      use to resume pagination.

    - **PageSize** *(integer) --*

      The size of each page.

    - **StartingToken** *(string) --*

      A token to specify where to start paginating. This is the ``NextToken`` from a previous
      response.
    """


_ListProjectsPaginateResponseprojectsTypeDef = TypedDict(
    "_ListProjectsPaginateResponseprojectsTypeDef",
    {"projectId": str, "projectArn": str},
    total=False,
)


class ListProjectsPaginateResponseprojectsTypeDef(
    _ListProjectsPaginateResponseprojectsTypeDef
):
    """
    Type definition for `ListProjectsPaginateResponse` `projects`

    Information about the metadata for a project.

    - **projectId** *(string) --*

      The ID of the project.

    - **projectArn** *(string) --*

      The Amazon Resource Name (ARN) of the project.
    """


_ListProjectsPaginateResponseTypeDef = TypedDict(
    "_ListProjectsPaginateResponseTypeDef",
    {"projects": List[ListProjectsPaginateResponseprojectsTypeDef], "NextToken": str},
    total=False,
)


class ListProjectsPaginateResponseTypeDef(_ListProjectsPaginateResponseTypeDef):
    """
    Type definition for `ListProjectsPaginate` `Response`

    - **projects** *(list) --*

      A list of projects.

      - *(dict) --*

        Information about the metadata for a project.

        - **projectId** *(string) --*

          The ID of the project.

        - **projectArn** *(string) --*

          The Amazon Resource Name (ARN) of the project.

    - **NextToken** *(string) --*

      A token to resume pagination.
    """


_ListResourcesPaginatePaginationConfigTypeDef = TypedDict(
    "_ListResourcesPaginatePaginationConfigTypeDef",
    {"MaxItems": int, "PageSize": int, "StartingToken": str},
    total=False,
)


class ListResourcesPaginatePaginationConfigTypeDef(
    _ListResourcesPaginatePaginationConfigTypeDef
):
    """
    Type definition for `ListResourcesPaginate` `PaginationConfig`

    A dictionary that provides parameters to control pagination.

    - **MaxItems** *(integer) --*

      The total number of items to return. If the total number of items available is more than the
      value specified in max-items then a ``NextToken`` will be provided in the output that you can
      use to resume pagination.

    - **PageSize** *(integer) --*

      The size of each page.

    - **StartingToken** *(string) --*

      A token to specify where to start paginating. This is the ``NextToken`` from a previous
      response.
    """


_ListResourcesPaginateResponseresourcesTypeDef = TypedDict(
    "_ListResourcesPaginateResponseresourcesTypeDef", {"id": str}, total=False
)


class ListResourcesPaginateResponseresourcesTypeDef(
    _ListResourcesPaginateResponseresourcesTypeDef
):
    """
    Type definition for `ListResourcesPaginateResponse` `resources`

    Information about a resource for a project.

    - **id** *(string) --*

      The Amazon Resource Name (ARN) of the resource.
    """


_ListResourcesPaginateResponseTypeDef = TypedDict(
    "_ListResourcesPaginateResponseTypeDef",
    {
        "resources": List[ListResourcesPaginateResponseresourcesTypeDef],
        "NextToken": str,
    },
    total=False,
)


class ListResourcesPaginateResponseTypeDef(_ListResourcesPaginateResponseTypeDef):
    """
    Type definition for `ListResourcesPaginate` `Response`

    - **resources** *(list) --*

      An array of resources associated with the project.

      - *(dict) --*

        Information about a resource for a project.

        - **id** *(string) --*

          The Amazon Resource Name (ARN) of the resource.

    - **NextToken** *(string) --*

      A token to resume pagination.
    """


_ListTeamMembersPaginatePaginationConfigTypeDef = TypedDict(
    "_ListTeamMembersPaginatePaginationConfigTypeDef",
    {"MaxItems": int, "PageSize": int, "StartingToken": str},
    total=False,
)


class ListTeamMembersPaginatePaginationConfigTypeDef(
    _ListTeamMembersPaginatePaginationConfigTypeDef
):
    """
    Type definition for `ListTeamMembersPaginate` `PaginationConfig`

    A dictionary that provides parameters to control pagination.

    - **MaxItems** *(integer) --*

      The total number of items to return. If the total number of items available is more than the
      value specified in max-items then a ``NextToken`` will be provided in the output that you can
      use to resume pagination.

    - **PageSize** *(integer) --*

      The size of each page.

    - **StartingToken** *(string) --*

      A token to specify where to start paginating. This is the ``NextToken`` from a previous
      response.
    """


_ListTeamMembersPaginateResponseteamMembersTypeDef = TypedDict(
    "_ListTeamMembersPaginateResponseteamMembersTypeDef",
    {"userArn": str, "projectRole": str, "remoteAccessAllowed": bool},
    total=False,
)


class ListTeamMembersPaginateResponseteamMembersTypeDef(
    _ListTeamMembersPaginateResponseteamMembersTypeDef
):
    """
    Type definition for `ListTeamMembersPaginateResponse` `teamMembers`

    Information about a team member in a project.

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user in IAM.

    - **projectRole** *(string) --*

      The role assigned to the user in the project. Project roles have different levels of
      access. For more information, see `Working with Teams
      <http://docs.aws.amazon.com/codestar/latest/userguide/working-with-teams.html>`__ in the
      *AWS CodeStar User Guide* .

    - **remoteAccessAllowed** *(boolean) --*

      Whether the user is allowed to remotely access project resources using an SSH
      public/private key pair.
    """


_ListTeamMembersPaginateResponseTypeDef = TypedDict(
    "_ListTeamMembersPaginateResponseTypeDef",
    {
        "teamMembers": List[ListTeamMembersPaginateResponseteamMembersTypeDef],
        "NextToken": str,
    },
    total=False,
)


class ListTeamMembersPaginateResponseTypeDef(_ListTeamMembersPaginateResponseTypeDef):
    """
    Type definition for `ListTeamMembersPaginate` `Response`

    - **teamMembers** *(list) --*

      A list of team member objects for the project.

      - *(dict) --*

        Information about a team member in a project.

        - **userArn** *(string) --*

          The Amazon Resource Name (ARN) of the user in IAM.

        - **projectRole** *(string) --*

          The role assigned to the user in the project. Project roles have different levels of
          access. For more information, see `Working with Teams
          <http://docs.aws.amazon.com/codestar/latest/userguide/working-with-teams.html>`__ in the
          *AWS CodeStar User Guide* .

        - **remoteAccessAllowed** *(boolean) --*

          Whether the user is allowed to remotely access project resources using an SSH
          public/private key pair.

    - **NextToken** *(string) --*

      A token to resume pagination.
    """


_ListUserProfilesPaginatePaginationConfigTypeDef = TypedDict(
    "_ListUserProfilesPaginatePaginationConfigTypeDef",
    {"MaxItems": int, "PageSize": int, "StartingToken": str},
    total=False,
)


class ListUserProfilesPaginatePaginationConfigTypeDef(
    _ListUserProfilesPaginatePaginationConfigTypeDef
):
    """
    Type definition for `ListUserProfilesPaginate` `PaginationConfig`

    A dictionary that provides parameters to control pagination.

    - **MaxItems** *(integer) --*

      The total number of items to return. If the total number of items available is more than the
      value specified in max-items then a ``NextToken`` will be provided in the output that you can
      use to resume pagination.

    - **PageSize** *(integer) --*

      The size of each page.

    - **StartingToken** *(string) --*

      A token to specify where to start paginating. This is the ``NextToken`` from a previous
      response.
    """


_ListUserProfilesPaginateResponseuserProfilesTypeDef = TypedDict(
    "_ListUserProfilesPaginateResponseuserProfilesTypeDef",
    {"userArn": str, "displayName": str, "emailAddress": str, "sshPublicKey": str},
    total=False,
)


class ListUserProfilesPaginateResponseuserProfilesTypeDef(
    _ListUserProfilesPaginateResponseuserProfilesTypeDef
):
    """
    Type definition for `ListUserProfilesPaginateResponse` `userProfiles`

    Information about a user's profile in AWS CodeStar.

    - **userArn** *(string) --*

      The Amazon Resource Name (ARN) of the user in IAM.

    - **displayName** *(string) --*

      The display name of a user in AWS CodeStar. For example, this could be set to both first
      and last name ("Mary Major") or a single name ("Mary"). The display name is also used to
      generate the initial icon associated with the user in AWS CodeStar projects. If spaces
      are included in the display name, the first character that appears after the space will
      be used as the second character in the user initial icon. The initial icon displays a
      maximum of two characters, so a display name with more than one space (for example "Mary
      Jane Major") would generate an initial icon using the first character and the first
      character after the space ("MJ", not "MM").

    - **emailAddress** *(string) --*

      The email address associated with the user.

    - **sshPublicKey** *(string) --*

      The SSH public key associated with the user in AWS CodeStar. If a project owner allows
      the user remote access to project resources, this public key will be used along with the
      user's private key for SSH access.
    """


_ListUserProfilesPaginateResponseTypeDef = TypedDict(
    "_ListUserProfilesPaginateResponseTypeDef",
    {
        "userProfiles": List[ListUserProfilesPaginateResponseuserProfilesTypeDef],
        "NextToken": str,
    },
    total=False,
)


class ListUserProfilesPaginateResponseTypeDef(_ListUserProfilesPaginateResponseTypeDef):
    """
    Type definition for `ListUserProfilesPaginate` `Response`

    - **userProfiles** *(list) --*

      All the user profiles configured in AWS CodeStar for an AWS account.

      - *(dict) --*

        Information about a user's profile in AWS CodeStar.

        - **userArn** *(string) --*

          The Amazon Resource Name (ARN) of the user in IAM.

        - **displayName** *(string) --*

          The display name of a user in AWS CodeStar. For example, this could be set to both first
          and last name ("Mary Major") or a single name ("Mary"). The display name is also used to
          generate the initial icon associated with the user in AWS CodeStar projects. If spaces
          are included in the display name, the first character that appears after the space will
          be used as the second character in the user initial icon. The initial icon displays a
          maximum of two characters, so a display name with more than one space (for example "Mary
          Jane Major") would generate an initial icon using the first character and the first
          character after the space ("MJ", not "MM").

        - **emailAddress** *(string) --*

          The email address associated with the user.

        - **sshPublicKey** *(string) --*

          The SSH public key associated with the user in AWS CodeStar. If a project owner allows
          the user remote access to project resources, this public key will be used along with the
          user's private key for SSH access.

    - **NextToken** *(string) --*

      A token to resume pagination.
    """
